@@ -52,7 +52,7 @@ brightness <- function(img, def, thresh = NULL, detrend = FALSE, quick = FALSE,
   if (!is.null(filt)) filt %<>% fix_filt()
   filt %<>% extend_for_all_chs(n_ch) %>% unlist() %>% as.character()
   swaps_atts <- extend_for_all_chs(
-    rlang::set_attrs(NA, auto = FALSE),
+    structure(NA, auto = FALSE),
     n_ch
   )
   thresh_atts <- extend_for_all_chs(NA, n_ch)
@@ -168,7 +168,7 @@ brightness_timeseries <- function(img, def, frames_per_set, overlap = FALSE,
   if (!is.null(filt)) filt %<>% fix_filt()
   filt %<>% extend_for_all_chs(n_ch) %>% unlist() %>% as.character()
   swaps_atts <- extend_for_all_chs(
-    rlang::set_attrs(NA, auto = FALSE),
+    structure(NA, auto = FALSE),
     n_ch
   )
   thresh_atts <- extend_for_all_chs(NA, n_ch)
