@@ -66,7 +66,7 @@ cc_number <- function(img, ch1 = 1, ch2 = 2,
   ch2 <- img[, , ch2, ]
   thresh_atts <- as.list(rep(NA, 2))
   swaps_atts <- extend_for_all_chs(
-    rlang::set_attrs(NA, auto = FALSE),
+    structure(NA, auto = FALSE),
     2
   )
   if (all(is.na(ch1))) {
@@ -186,7 +186,7 @@ cc_number_timeseries <- function(img, frames_per_set, overlap = FALSE,
   ch2 <- img[, , ch2, ]
   thresh_atts <- as.list(rep(NA, 2))
   swaps_atts <- extend_for_all_chs(
-    rlang::set_attrs(NA, auto = FALSE),
+    structure(NA, auto = FALSE),
     2
   )
   if (all(is.na(ch1))) {
