@@ -2,17 +2,17 @@ context("Class constructors")
 
 test_that("Class construction edge cases function correctly", {
   img <- array(runif(8), dim = rep(2, 3))
-  eg <- number_img(img, "N", 4, rlang::set_attrs(8, auto = TRUE), NA)
+  eg <- number_img(img, "N", 4, structure(8, auto = TRUE), NA)
   expect_equal(attr(eg, "thresh"), rep(4, 2))
   expect_equal(
     attr(eg, "swaps"),
-    rlang::set_attrs(c(8, 8), auto = c(TRUE, TRUE))
+    structure(c(8, 8), auto = c(TRUE, TRUE))
   )
   expect_error(brightness_img(img, "a", 4, 9, NA), "def.*must.*one of")
   expect_error(brightness_ts_img(img, "a", 10, 4, 9, NA), "def.*must.*one of")
   x <- list(
-    rlang::set_attrs(4, a = 0),
-    rlang::set_attrs(5, b = 0)
+    structure(4, a = 0),
+    structure(5, b = 0)
   )
   ans <- 4:5
   attributes(ans) <- list(a = c(0, NA), b = c(NA, 0))
@@ -20,27 +20,27 @@ test_that("Class construction edge cases function correctly", {
   img <- array(runif(3^3), dim = rep(3, 3))
   expect_error(number_img(
     img, "n", 5,
-    rlang::set_attrs(4:6, auto = rep(FALSE, 2)),
+    structure(4:6, auto = rep(FALSE, 2)),
     NA
   ), "auto.*attribute.*swaps.*same length.*swaps.*itself")
   expect_equal(
     number_img(
       img, "n", 5,
-      rlang::set_attrs(4:6, auto = FALSE), "med"
+      structure(4:6, auto = FALSE), "med"
     ),
     number_img(
       img, "n", 5,
-      rlang::set_attrs(4:6, auto = rep(FALSE, 3)), rep("median", 3)
+      structure(4:6, auto = rep(FALSE, 3)), rep("median", 3)
     )
   )
   expect_error(
-    number_img(img, "n", 5, rlang::set_attrs(4:6, auto = NA), NA),
+    number_img(img, "n", 5, structure(4:6, auto = NA), NA),
     "swaps.*att.*not NA"
   )
   expect_error(
     number_img(
       img, "n", 5,
-      rlang::set_attrs(4:5, auto = rep(FALSE, 2)), NA
+      structure(4:5, auto = rep(FALSE, 2)), NA
     ),
     "thresh.*swaps.*filt.*same.*channels"
   )
@@ -54,14 +54,14 @@ test_that("Class construction edge cases function correctly", {
   expect_error(
     cc_number_img_common(
       img, 1:2,
-      rlang::set_attrs(1, auto = TRUE), "s"
+      structure(1, auto = TRUE), "s"
     ),
     "Assertion on.*swaps.*failed: Must have length 2.* has length 1"
   )
   expect_error(
     cc_number_img_common(
       img, 1:2,
-      rlang::set_attrs(1, auto = 1:2), "s"
+      structure(1, auto = 1:2), "s"
     ),
     paste0(
       "The 'auto' attribute of `swaps` must be the same length\\s?",
@@ -72,7 +72,7 @@ test_that("Class construction edge cases function correctly", {
   expect_error(
     cc_number_img_common(
       img, 1:2,
-      rlang::set_attrs(1, auto = NA), "s"
+      structure(1, auto = NA), "s"
     ),
     paste0(
       "Each element of `swaps` must have an associated\\s?",
@@ -84,12 +84,12 @@ test_that("Class construction edge cases function correctly", {
   expect_equal(
     cc_number_img_common(
       img, 1:2,
-      rlang::set_attrs(1:2, auto = rep(TRUE, 2)),
+      structure(1:2, auto = rep(TRUE, 2)),
       "smooth"
     ),
     cc_number_img_common(
       img, 1:2,
-      rlang::set_attrs(1:2, auto = TRUE),
+      structure(1:2, auto = TRUE),
       "smooth"
     )
   )
